summaryrefslogtreecommitdiffstats
path: root/kdgantt/KDGanttSemiSizingControl.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kdgantt/KDGanttSemiSizingControl.cpp')
-rw-r--r--kdgantt/KDGanttSemiSizingControl.cpp32
1 files changed, 16 insertions, 16 deletions
diff --git a/kdgantt/KDGanttSemiSizingControl.cpp b/kdgantt/KDGanttSemiSizingControl.cpp
index dcc2f40d..bfaa161d 100644
--- a/kdgantt/KDGanttSemiSizingControl.cpp
+++ b/kdgantt/KDGanttSemiSizingControl.cpp
@@ -247,9 +247,9 @@ KDGanttSemiSizingControl::ArrowPosition KDGanttSemiSizingControl::arrowPosition(
void KDGanttSemiSizingControl::init()
{
_but = new TQPushButton( this );
- _but->setSizePolicy( TQSizePolicy( TQSizePolicy::Fixed, TQSizePolicy::Fixed ) );
+ _but->tqsetSizePolicy( TQSizePolicy( TQSizePolicy::Fixed, TQSizePolicy::Fixed ) );
connect( _but, TQT_SIGNAL( clicked() ), this, TQT_SLOT(changeState()) );
- _layout = 0;
+ _tqlayout = 0;
TQWhatsThis::add( _but, "Click on this button to show the \nlegend at the bottom of the widget");
TQToolTip::add( _but, "Show / hide legend");
@@ -258,19 +258,19 @@ void KDGanttSemiSizingControl::init()
void KDGanttSemiSizingControl::setup()
{
- //-------------------------------------------------- Setup layout
- delete _layout;
- TQBoxLayout* butLayout; // _layout will delete me
+ //-------------------------------------------------- Setup tqlayout
+ delete _tqlayout;
+ TQBoxLayout* butLayout; // _tqlayout will delete me
if ( _orient == Qt::Horizontal || isMinimized() )
- _layout = new TQHBoxLayout( this );
+ _tqlayout = new TQHBoxLayout( this );
else
- _layout = new TQVBoxLayout( this );
+ _tqlayout = new TQVBoxLayout( this );
if ( _orient == Qt::Vertical && !isMinimized() )
- butLayout = new TQHBoxLayout( _layout );
+ butLayout = new TQHBoxLayout( _tqlayout );
else
- butLayout = new TQVBoxLayout( _layout );
+ butLayout = new TQVBoxLayout( _tqlayout );
@@ -306,9 +306,9 @@ void KDGanttSemiSizingControl::setup()
widget = _maximizedWidget;
if( widget ) {
if ( _arrowPos == Before || _orient == Qt::Vertical && !isMinimized() )
- _layout->addWidget( widget, 1 );
+ _tqlayout->addWidget( widget, 1 );
else
- _layout->insertWidget( 0, widget, 1 );
+ _tqlayout->insertWidget( 0, widget, 1 );
}
************************************************** */
// hack for the usage in KDGantt as pop-up legend widget
@@ -319,16 +319,16 @@ void KDGanttSemiSizingControl::setup()
widget = _minimizedWidget;
if( widget ) {
if ( _arrowPos == Before || _orient == Qt::Vertical && !isMinimized() )
- _layout->addWidget( widget, 1 );
+ _tqlayout->addWidget( widget, 1 );
else
- _layout->insertWidget( 0, widget, 1 );
+ _tqlayout->insertWidget( 0, widget, 1 );
}
}
else {
if ( _arrowPos == Before || _orient == Qt::Vertical && !isMinimized() )
- _layout->addStretch( 1 );
+ _tqlayout->addStretch( 1 );
else
- _layout->insertStretch( 0, 1 );
+ _tqlayout->insertStretch( 0, 1 );
widget = _maximizedWidget;
// the following is only the special case
// arrowPos == Before and _orient == Qt::Vertical
@@ -395,7 +395,7 @@ TQPixmap KDGanttSemiSizingControl::pixmap( Direction direction ) {
TQPainter p( &pix );
p.setPen( black );
- p.setBrush( colorGroup().button() );
+ p.setBrush( tqcolorGroup().button() );
p.drawPolygon( arr );
TQBitmap bit( s, s );
bit.fill( color0 );